#!/bin/bash

cdr2mask () {
  # From https://stackoverflow.com/questions/20762575/explanation-of-convertor-of-cidr-to-netmask-in-linux-shell-netmask2cdir-and-cdir
  # Number of args to shift, 255..255, first non-255 byte, zeroes
  set -- $(( 5 - ("${1}" / 8) )) 255 255 255 255 $(( (255 << (8 - ("${1}" % 8))) & 255 )) 0 0 0
  if [[ "${1}" -gt 1 ]] ; then
    shift "${1}"
  else
    shift
  fi
  echo "${1:-0}.${2:-0}.${3:-0}.${4:-0}"
}

show_network_configuration() {
  if "${AUTODETECT:-false}" ; then
    export EXTERNAL_DEV="$(ip -4 r | awk '/default/ {print $5; exit}')"
    external_ip_data=( $( ip -4 addr show "${EXTERNAL_DEV}" | sed -rn 's/^[ ]+inet ([0-9]+(\.[0-9]+){3})\/([0-9]+).*$/\1 \3/p' ) )
    export EADDR="${external_ip_data[0]}"
    current_netmask="$( cdr2mask "${external_ip_data[1]}" )"
    export EXTERNAL_NETMASK="${current_netmask}"
    unset external_ip_data current_netmask
    export GW="$(ip route show dev "${EXTERNAL_DEV}" | awk '/^default via/ {print $3; exit}')"
  fi

  log_info "You have entered the following configuration:"
  if "${PRO}" || "${CARRIER}" ; then
    log_info "             IP1: ${IP1}"
    log_info "             IP2: ${IP2}"
    log_info "    IP_HA_SHARED: ${IP_HA_SHARED}"
    log_info "INTERNAL_NETMASK: ${INTERNAL_NETMASK}"
    log_info "           EADDR: ${EADDR}"
  fi
  log_info "       INTERFACE: ${EXTERNAL_DEV}"
  log_info "              IP: ${EADDR}"
  log_info "         NETMASK: ${EXTERNAL_NETMASK}"
  log_info "              GW: ${GW}"
  log_info "     NAMESERVERS: ${NAMESERVER}"

  if "${AUTODETECT:-false}" ; then
    log_info "These parameters were collected from the current network configuration by the option AUTODETECT"
  fi
  log_info "If these parameters are not appropriate you can change them in /etc/ngcp-installer/config_deploy.inc"
  cfg_ask_user "Are those values correct?"
  log_info "Accept values"
}
