#!/bin/bash

enable_vm_services() {
  if ! "${ENABLE_VM_SERVICES:-false}" ; then
    log_info "No need to enable any VM services here"
    return
  fi

  if ${PRO} || ${CARRIER} ; then
    log_info "Enabling presence for PRO/Carrier installations"
    ngcpcfg set "${CONFIG_YML}" "kamailio.proxy.presence.enable=yes"
    log_info "Enabling debug for netscript PRO/Carrier installation only"
    ngcpcfg set "${CONFIG_YML}" "bootenv.netscript.debug=yes"
    log_info "Enabling voisniff for PRO/Carrier installations"
    ngcpcfg set "${CONFIG_YML}" "voisniff.admin_panel=yes"
    ngcpcfg set "${CONFIG_YML}" "voisniff.daemon.start=yes"
    ngcpcfg set "${CONFIG_YML}" "voisniff.daemon.mysql_dump.num_threads=2"
    ngcpcfg set "${CONFIG_YML}" "voisniff.daemon.threads_per_interface=2"
  fi

  log_info "Enabling SSH on all the interfaces for CE/PRO/Carrier installations"
  ngcpcfg set "${CONFIG_YML}" "sshd.listen_addresses.APPEND='0.0.0.0'"
  ngcpcfg set "${CONFIG_YML}" "sshd.authorized_keys_file='%h/.ssh/authorized_keys %h/.ssh/sipwise_vagrant_key'"
  ngcpcfg set "${CONFIG_YML}" "sudo.logging.enable=no"
  ngcpcfg set "${CONFIG_YML}" "security.ngcp_panel.scripts.restapi.sslverify=no"
  ngcpcfg set "${CONFIG_YML}" "general.production=no"

  log_info "Enabling backup tools on CE/PRO/Carrier installations"
  ngcpcfg set "${CONFIG_YML}" "backuptools.cdrexport_backup.enable=yes"
  ngcpcfg set "${CONFIG_YML}" "backuptools.etc_backup.enable=yes"
  ngcpcfg set "${CONFIG_YML}" "backuptools.mysql_backup.enable=yes"

  log_info "Disable systemd-getty TTYVTDisallocate for vagrant VM (to keep errors on console)"
  ngcpcfg set "${CONFIG_YML}" "systemd.getty.ttyvtdisallocate=no"

  if ${PRO} || ${CARRIER} ; then
    log_info "Enabling ngcp-rtcengine, fileshare and janus for PRO installation only"
    ngcpcfg set "${CONFIG_YML}" "rtcengine.enable=yes"
    ngcpcfg set "${CONFIG_YML}" "fileshare.enable=yes"
    ngcpcfg set "${CONFIG_YML}" "janus.enable=yes"
  fi
}

vm_net_configuration() {
  local host="${1}"

  if ! "${ENABLE_VM_SERVICES}" ; then
    log_info "No need to run vm_net_configuration"
    return
  fi

  log_info "Enabling on host ${host} eth0 interface with dhcp, for Vagrant"
  ngcp-network --host="${host}" --set-interface=eth0 --dhcp=yes

  log_info "Enabling on host ${host} NGCP selfcare and admin interfaces on eth0 (web_ext and web_int types)"
  ngcp-network --host="${host}" --set-interface=eth0 --type=web_ext --type=web_int
}
